summaryrefslogtreecommitdiffstats
path: root/vendor/winnow/src/_topic/partial.rs
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/winnow/src/_topic/partial.rs')
-rw-r--r--vendor/winnow/src/_topic/partial.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/vendor/winnow/src/_topic/partial.rs b/vendor/winnow/src/_topic/partial.rs
index 263d7f127..19895d35a 100644
--- a/vendor/winnow/src/_topic/partial.rs
+++ b/vendor/winnow/src/_topic/partial.rs
@@ -21,7 +21,7 @@
//! Caveats:
//! - `winnow` takes the approach of re-parsing from scratch. Chunks should be relatively small to
//! prevent the re-parsing overhead from dominating.
//! - Parsers like [`many0`] do not know when an `eof` is from insufficient data or the end of the
//! stream, causing them to always report [`Incomplete`].
//!
//! # Example
@@ -38,9 +38,9 @@
#![allow(unused_imports)] // Used for intra-doc links
+use crate::binary::length_value;
+use crate::combinator::repeat;
use crate::error::ErrMode::Incomplete;
use crate::error::Needed;
-use crate::multi::length_value;
-use crate::multi::many0;
use crate::stream::Partial;
use crate::stream::StreamIsPartial;
@@ -21,7 +21,7 @@
//! - `winnow` takes the approach of re-parsing from scratch. Chunks should be relatively small to
//! prevent the re-parsing overhead from dominating.
-//! - Parsers like [`many0`] do not know when an `eof` is from insufficient data or the end of the
+//! - Parsers like [`repeat`] do not know when an `eof` is from insufficient data or the end of the
//! stream, causing them to always report [`Incomplete`].
//!